
import ddf.minim.*;

AudioPlayer [] players;
float [] params;
float [] levels;

Minim minim;

void setup() {
  size(1024, 240, P2D);

  minim = new Minim(this);

  int samps = 2048;

  players = new AudioPlayer[5];

  players[0] = minim.loadFile("ahhs.mp3", samps);
  players[1] = minim.loadFile("beats.mp3", samps);
  players[2] = minim.loadFile("doops.mp3", samps);
  players[3] = minim.loadFile("phats.mp3", samps);
  players[4] = minim.loadFile("screams.mp3", samps);

  params = new float [] {
    17,   0.1, 0.1, 0.5,
    20,   0.8, 0.1, 0.1,
    28,   0.8, 0.7, 0.2,
    10,  0.2, 0.6, 0.5,
    13,   0.9, 0.8, 0.9  };
    
  levels = new float[] {0,0,0,0,0};

  for(int chan = 0; chan < players.length; chan++) {
    players[chan].loop();
  }
  
  colorMode(RGB, 1, 1, 1, 1);
  smooth();
}

void mousePressed() {
  for(int chan = 0; chan < players.length; chan++) {
    players[chan].rewind(); 
  } 
}

void draw() {
  background(0);

  for(int chan = 0; chan < players.length; chan++) {
    levels[chan] = sqrt(players[chan].mix.level())*2;
  }

  float noiseFloor = -48;

  strokeWeight(1);
  for(int col = 0; col < width; col++) {
    float t = map(col, 0, width, 0, 1);
    
    for(int chan = 0; chan < players.length; chan++) {
      int p = 4*chan;

      float gain = map(-cos(t*params[p+0]), -1, 1, noiseFloor, 0);
      int row = (int) map(gain, noiseFloor, 0, height-10, 0+10);

      stroke(params[p+1], params[p+2], params[p+3], levels[chan]);
      line(col, row-10*levels[chan], col, row+10*levels[chan]);
    }
  }
  
  strokeWeight(2);
  stroke(1,1,1);
  
  stroke(1,1,1);
  line(mouseX, 0, mouseX, height);
  
  float userT = map(mouseX, 0, width, 0, 1);
  for(int chan = 0; chan < players.length; chan++) {
      int p = 4*chan;
      float gain = map(-cos(userT*params[p+0]), -1, 1, noiseFloor, 0);
      int row = (int) map(gain, noiseFloor, 0, height-5, 0+5);
      players[chan].setGain(gain);
      stroke(params[p+1], params[p+2], params[p+3]);
      line(mouseX-50*levels[chan],row, mouseX+50*levels[chan], row);
  }
  
}

void stop() {
  for(int i = 0; i < players.length; i++) {
    players[i].close();
  }

  minim.stop();

  super.stop();
}

